(function() {
  var App, Media;

  App = App || {};

  App.Models = App.Models || {};

  App.Collections = App.Collections || {};

  App.Views = App.Views || {};

  App.Models.MediaModelSize = Backbone.Model.extend({
    urlRoot: '/manager/midias-model/sizes',
    validate: function(attrs, options) {
      if (isNaN(parseInt(attrs.width)) || isNaN(parseInt(attrs.height))) {
        return 'Altura e largura devem ser números inteiros';
      }
      if (prefix === '') {
        return 'Preencha o prefixo';
      }
    }
  });

  App.Collections.MediaModelSizes = Backbone.Collection.extend({
    model: App.Models.MediaModelSize,
    url: '/manager/midias-model/sizes'
  });

  App.Views.MediaModelSizes = Backbone.View.extend({
    tagName: 'div',
    template: _.template($('#template-sizes').html()),
    events: {
      'click #btn-save-size': 'save'
    },
    initialize: function() {
      this.collection.on('add', this.addOne, this);
      return this.render();
    },
    render: function() {
      this.$el.html(this.template());
      this.collection.each(this.addOne, this);
      return this;
    },
    addOne: function(size) {
      var sizeView;
      sizeView = new App.Views.MediaModelSize({
        model: size
      });
      return this.$('#sizes').append(sizeView.render().el);
    },
    save: function() {
      var resize;
      resize = $('#resize').prop('checked') ? 1 : 0;
      this.collection.create({
        'media_model_id': Media.id,
        'prefix': $('#prefix').val(),
        'width': $('#width').val(),
        'height': $('#height').val(),
        'resize': resize
      }, {
        wait: true
      });
      return this.clearForm();
    },
    clearForm: function() {
      $('#prefix').val('');
      $('#width').val('');
      $('#height').val('');
      return $('#resize').prop('checked', false);
    }
  });

  App.Views.MediaModelSize = Backbone.View.extend({
    tagName: 'tr',
    template: _.template($('#template-size-item').html()),
    events: {
      'click .btn-delete-size': 'delete'
    },
    initialize: function() {
      return this.model.on('destroy', this.unrender, this);
    },
    render: function() {
      this.$el.html(this.template(this.model.toJSON()));
      return this;
    },
    "delete": function(e) {
      e.preventDefault();
      return this.model.destroy();
    },
    unrender: function() {
      return this.remove();
    }
  });

  Media = {};

  Media.$modalSizes = $('#modal-sizes');

  Media.id = null;

  Media.init = function() {
    return $('.btn-open-sizes').on('click', function(e) {
      var $this;
      e.preventDefault();
      $this = $(this);
      Media.id = $this.data('id');
      Media.fetchSizes();
      return Media.openModal();
    });
  };

  Media.fetchSizes = function() {
    var sizesCollections;
    sizesCollections = new App.Collections.MediaModelSizes();
    return sizesCollections.fetch({
      data: {
        'id': Media.id
      }
    }).success(function() {
      var sizesView;
      sizesView = new App.Views.MediaModelSizes({
        collection: sizesCollections
      });
      return Media.$modalSizes.find('.modal-body').html(sizesView.el);
    });
  };

  Media.openModal = function() {
    return Media.$modalSizes.modal('show');
  };

  Media.closeModal = function() {
    return Media.$modalSizes.modal('close');
  };

  Media.init();

}).call(this);
