<?php namespace EscapeWork\Manager\Medias\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\Medias\Upload;
use EscapeWork\Manager\Medias\Repositories\MediaRepository;
use EscapeWork\Manager\Medias\Repositories\MediaModelRepository;
use App;
use Config;
use View;
use Input;
use Redirect;
use Response;

class MediaController extends ManagerController
{

    public function __construct(
        MediaRepository $media,
        MediaModelRepository $mediaModel)
    {
        parent::__construct();

        $this->media      = $media;
        $this->mediaModel = $mediaModel;
    }

    /**
     * Configurando o model do produto, adicionando na view e setando a mensagem padrão
     */
    protected function configure($media_model_id, $model_id)
    {
        $this->mediaModel->findOrFail($media_model_id);

        $this->model = new $this->mediaModel->model;
        $this->model = $this->model->findOrFail($model_id);

        $this->media->model_id = $this->model->id;
        $this->media->setMediaModel($this->mediaModel->model);
    }

    public function index($media_model_id, $model_id)
    {
        $this->configure($media_model_id, $model_id);

        $view              = View::make(Config::get('manager-medias::views.medias.index'));
        $view->medias      = $this->media->getMedias();
        $view->mediaModel  = $this->mediaModel;
        $view->model_title = $this->mediaModel->model_title;
        $view->model       = $this->model;

        return $view;
    }

    public function store($media_model_id, $model_id)
    {
        $this->configure($media_model_id, $model_id);

        foreach (Input::file('files') as $file) {
            $this->media->insert($file);
        }

        return Redirect::route('manager.medias.index', [$this->mediaModel->id, $this->model->id]);
    }

    public function update($media_model_id, $model_id, $id)
    {
        $this->configure($media_model_id, $model_id);

        if (! $this->media = $this->media->find($id)) {
            return Response::json(array('error' => 'Foto não encontrada'));
        }

        $this->media->fill(Input::all());
        $this->media->save();

        return Response::json(array(
            'message' => 'A foto foi atualizada com sucesso!',
            'id'      => $this->media->id
        ));
    }

    public function updateOrder($media_model_id, $model_id, $id)
    {
        $this->configure($media_model_id, $model_id);

        if (! $this->media = $this->media->find($id)) {
            return Response::json(array('error' => 'Foto não encontrada'));
        }

        $this->media->order = Input::get('order');
        $this->media->save();

        return Response::json(array(
            'message' => 'A foto foi atualizada com sucesso!',
            'id'      => $this->media->id
        ));
    }

    public function destroy($media_model_id, $model_id, $id)
    {
        $this->configure($media_model_id, $model_id);
        $this->media = $this->media->findOrFail($id);

        if ($this->media->delete()) {
            return Redirect::route('manager.medias.index', [$this->mediaModel->id, $this->model->id])
                        ->with('message', 'A mídia foi excluída com sucesso!');
        }

        return Redirect::route('manager.medias.index', [$this->mediaModel->id, $this->model->id])
                    ->with('error', 'Houve um erro ao excluir a mídia.');
    }

    public function destroyAll($media_model_id, $model_id)
    {
        $this->configure($media_model_id, $model_id);
        $this->media->deleteAll();

        return Redirect::route('manager.medias.index', [$this->mediaModel->id, $this->model->id])
                    ->with('message', 'As fotos foram excluídas com sucesso!');
    }
}
