<?php namespace EscapeWork\Manager\Medias\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\Medias\Models\MediaModel;
use EscapeWork\Manager\Medias\Repositories\MediaModelSizeRepository;
use EscapeWork\Manager\Medias\Repositories\MediaModelRepository;
use EscapeWork\Manager\Medias\Repositories\MediaRepository;
use App;
use View;
use Input;
use Redirect;

class MediaModelController extends ManagerController
{

    public function __construct(
        MediaModelSizeRepository $mediaModelSize,
        MediaModelRepository $mediaModel,
        MediaRepository $media)
    {
        parent::__construct();

        $this->mediaModelSize = $mediaModelSize;
        $this->mediaModel     = $mediaModel;
        $this->media          = $media;
    }

    public function index()
    {
        $view              = View::make('manager-medias::models.index');
        $view->mediasModel = $this->mediaModel->all();

        return $view;
    }

    public function create()
    {
        $this->mediaModel->fill(Input::old());
        $view             = View::make('manager-medias::models.form');
        $view->edit       = false;
        $view->mediaModel = $this->mediaModel;

        return $view;
    }

    public function store()
    {
        $this->mediaModel->fill(Input::all());
        if (! $this->mediaModel->validate()) {
            return Redirect::route('manager.medias.models.create')
                    ->withInput()
                    ->with('errors', MediaModel::$messages);
        }

        $this->mediaModel->save();

        return Redirect::route('manager.medias.models.index')
                ->with('message', 'O model <strong>'.$this->mediaModel->model.'</strong> foi inserido com sucesso!');
    }

    public function edit($id)
    {
        if (! $this->mediaModel = $this->mediaModel->find($id)) {
            return Redirect::route('manager.medias.models.index')
                    ->with('error', 'Model não encontrado');
        }

        $view             = View::make('manager-medias::models.form');
        $view->edit       = true;
        $view->mediaModel = $this->mediaModel;
        return $view;
    }

    public function update($id)
    {
        if (! $this->mediaModel = $this->mediaModel->find($id)) {
            return Redirect::route('manager.medias.models.index')
                    ->with('error', 'Model não encontrado');
        }

        $this->mediaModel->fill(Input::all());
        $this->mediaModel->save();

        return Redirect::route('manager.medias.models.index')
                ->with('message', 'O model <strong>'.$this->mediaModel->model.'</strong> foi alterado com sucesso!');
    }

    public function destroy($id)
    {
        if (! $this->mediaModel = $this->mediaModel->find($id)) {
            return Redirect::route('manager.medias.models.index')
                    ->with('error', 'Model não encontrado');
        }

        # validando se existem midias
        $medias = $this->media->where('media_model', '=', $this->mediaModel->model)->get();
        if (count($medias) > 0) {
            return Redirect::route('manager.medias.models.index')
                    ->with('error', 'O model <strong>'.$this->mediaModel->model.'</strong> possuí <strong>'.count($medias).'</strong> mídias e não pode ser excluído.');
        }

        # excluindo os tamanhos
        $this->mediaModelSize->where('media_model_id', '=', $this->mediaModel->id)->delete();
        $this->mediaModel->delete();

        return Redirect::route('manager.medias.models.index')
                ->with('message', 'O model <strong>'.$this->mediaModel->model.'</strong> foi excluído com sucesso!');
    }
}
