<?php namespace EscapeWork\Manager\Medias\Models;

use EscapeWork\LaravelHelpers\BaseModel;
use EscapeWork\Manager\Medias\Helpers\Mediable;

class MediaModel extends BaseModel
{

    /**
     * Table
     */
    protected $table = 'manager_media_models';

    /**
     * Regras para validação
     */
    public $validationRules = array(
        'model' => array('required', 'unique:media_models,model,:id:'),
    );

    /**
     * Mensagens para validação
     */
    public $validationMessages = array(
        'model.required' => 'O nome da tabela é obrigatório',
        'model.unique'   => 'O model digitado já existe',
    );

    /**
     * Fillable fields
     */
    protected $fillable = array(
        'id',
        'model',
        'model_title',
        'model_route',
        'page_title',
    );

    /**
     * Cache para a rota do media model
     */
    public static $_cacheMediaModel = null;

    public function sizes()
    {
        return $this->hasMany('EscapeWork\Manager\Medias\Models\MediaModelSize', 'media_model_id');
    }

    public static function seed($data)
    {
        if (! $model = static::where('model', '=', $data['model'])->first()) {
            $model = new static;
        }

        $model->fill(array_except($data, ['sizes']));
        $model->save();

        foreach ($data['sizes'] as $size) {
            $mediaModelSize = MediaModelSize::where('media_model_id', '=', $model->id)
                                            ->where('prefix', '=', $size['prefix'])
                                            ->first();

            if (! $mediaModelSize) {
                $mediaModelSize = new MediaModelSize;
            }

            $mediaModelSize->fill(array_merge(
                $size,
                array('media_model_id' => $model->id)
            ));
            $mediaModelSize->save();
        }
    }

    public static function byModel(Mediable $model)
    {
        if (static::$_cacheMediaModel) {
            return static::$_cacheMediaModel;
        }

        return static::$_cacheMediaModel = static::where('model', '=', $model->getMediaModel())
                                          ->first();
    }
}
