@extends(Config::get('manager::views.layouts.master'))

@section('content')
    <ul class="breadcrumb">
        <li><a href="{{ route('manager.home') }}">Home</a></li>
        @if (! is_null($mediaModel->page_title))
            <li><a href="{{ route($mediaModel->model_route ) }}">{{ $mediaModel->page_title }}</a></li>
        @endif
        <li>{{ $model->$model_title }}</li>
        <li class="active">Fotos</li>
    </ul><!-- .breadcrumb -->

    <div class="page-header">
        <div class="row">
            <div class="col-sm-9">
                <h3>{{ $model->$model_title }} <small>Fotos</small></h3>
            </div><!-- .pull-left -->

            <div class="col-sm-3">
                <a href="{{ route($mediaModel->model_route) }}" class="btn btn-default btn-small"><i class="glyphicon glyphicon-arrow-left"></i> voltar</a>
                <a href="{{ route('manager.medias.destroyAll', array($mediaModel->id, $model->id)) }}" class="btn btn-small btn-danger" data-delete><i class="glyphicon glyphicon-trash"></i> Excluir todas as fotos</a>
            </div><!-- .pull-right -->
        </div>
    </div><!-- .page-header -->

    @include('manager::inc.messages')

    <form action="{{ route('manager.medias.store', [$mediaModel->id, $model->id]) }}" method="post" enctype="multipart/form-data" class="form-horizontal" id="form-medias">
        <fieldset>
            <legend>Inserir fotos</legend>

            <div class="form-group">
                <label for="files" class="col-sm-2 control-label">Selecione as imagens</label>

                <div class="col-sm-8">
                    <div class="input-append">
                        <input type="file" name="files[]" id="files" accept="image/jpg,image/jpeg,image/png" class="form-control" required multiple>

                        <p class="help-block">Apenas imagens do tipo <strong>jpg</strong> e <strong>png</strong> são aceitas.<br>
                        Tamanho máximo de <strong>{{ ini_get('post_max_size') }}B</strong>.</p>
                    </div>
                </div><!-- .controls -->
            </div><!-- .control-group -->

            <div class="form-group">
                <div class="col-sm-offset-2 col-sm-10">
                    <button type="submit" class="btn btn-primary js-btn-submit" data-loading-text="Salvando...">Inserir fotos</button>
                </div>
            </div>
        </fieldset>
    </form>

    <hr>

    @if (count($medias) > 0)
        <p>Para alterar a ordem das fotos, clique e arraste a foto até a posição desejada.</p>

        <div class="row js-thumbnails">
            @foreach ($medias as $media)
                <div class="col-xs-6 col-md-3" data-media data-id="{{ $media->id }}">
                    <div class="thumbnail" style="cursor: move">
                        <div class="thumbnail-img" style="height: 200px; overflow: hidden;">
                            <img src="{{ asset('files/medias/manager-' . $media->file) }}" alt="{{ $media->legend }}" style="width: 100%;">
                        </div>

                        <div class="caption">
                            <form action="{{ route('manager.medias.update', [$mediaModel->id, $model->id, $media->id]) }}" medthod="post" class="js-form-media-update">
                                <input type="hidden" name="_method" value="put">

                                <input type="text" name="legend" class="form-control input-sm" value="{{ $media->legend }}" placeholder="Legenda">

                                @if (! in_array('credits', Config::get('manager-medias::hidden')))
                                    <input type="text" name="credits" class="form-control input-sm" value="{{ $media->credits }}" placeholder="Créditos">
                                @endif

                                <div class="pull-right btn-group btn-group-sm" style="margin: 10px 0 0 0;">
                                    <button type="submit" class="btn btn-primary btn-small js-btn-submit" title="Atualizar" data-id="{{ $media->id }}">
                                        <span class="glyphicon glyphicon-refresh"></span>
                                        Atualizar
                                    </button>

                                    <a href="{{ route('manager.medias.destroy', array($mediaModel->id, $model->id, $media->id)) }}" class="btn btn-danger btn-small" title="Excluir" data-delete="true">
                                        <span class="glyphicon glyphicon-trash"></span>
                                        Excluir
                                    </a>
                                </div><!-- .pull-right -->
                            </form>

                            <div class="clearfix"></div>
                        </div><!-- .caption -->
                    </div><!-- .thumbnail -->
                </div>
            @endforeach
        </div>
    @else
        <p>
            Nenhuma foto foi cadastrada para o produto até o momento.
        </p>
    @endif
@stop

@section('scripts')
    @parent

    <!-- The Iframe Transport is required for browsers without support for XHR file uploads -->
    <script type="text/javascript" src="{{ asset('packages/escapework/manager-medias/components/blueimp-file-upload/js/jquery.iframe-transport.js') }}"></script>
    <script type="text/javascript" src="{{ asset('packages/escapework/manager-medias/components/blueimp-file-upload/js/jquery.fileupload.js') }}"></script>
    <script type="text/javascript" src="{{ asset('packages/escapework/manager-medias/components/blueimp-file-upload/js/jquery.fileupload-process.js') }}"></script>
    <script type="text/javascript" src="{{ asset('packages/escapework/manager-medias/components/blueimp-file-upload/js/jquery.fileupload-image.js') }}"></script>
    <script type="text/javascript" src="{{ asset('packages/escapework/manager-medias/components/blueimp-file-upload/js/jquery.fileupload-validate.js') }}"></script>

    <script type="text/javascript" src="{{ asset('packages/escapework/manager-medias/assets/javascripts/js/index.js') }}"></script>
@stop
